camelot.camelot.view.controls.schemer.Schemer

Package camelot :: Package camelot :: Package view :: Package controls :: Module schemer :: Class Schemer |
[hide private]
[frames] | no frames]

# Class Schemer

Instance Methods | [hide private]
__init__(self, styledict=`{``'``BorderColor``'``:` `'``(101, 147, 207)``'``,` `'``ButtonMouseOverBegin``'``:` `'``(2``...`) |
bordercolor(self) |
captionbackground(self) |
captiontextcolor(self) |
fourcolorgradient(self, rgb1, rgb2, rgb3, rgb4) |
hoveredbackground(self) |
normalbackground(self) |
selectedbackground(self, inverted=False) |
selectedcolor(self) |
textcolor(self) |
twocolorgradient(self, rgb1, rgb2) |